==> fsspec_xrootd-0.1.0.tar.gz: fsspec_xrootd-0.1.0/README.md <==
# fsspec-xrootd

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]
[![Code style: black][black-badge]][black-link]

[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

[![GitHub Discussion][github-discussions-badge]][github-discussions-link]
[![Gitter][gitter-badge]][gitter-link]

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/CoffeaTeam/fsspec-xrootd/workflows/CI/badge.svg
[actions-link]:             https://github.com/CoffeaTeam/fsspec-xrootd/actions
[black-badge]:              https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]:               https://github.com/psf/black
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/fsspec-xrootd
[conda-link]:               https://github.com/conda-forge/fsspec-xrootd-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/CoffeaTeam/fsspec-xrootd/discussions
[gitter-badge]:             https://badges.gitter.im/https://github.com/CoffeaTeam/fsspec-xrootd/community.svg
[gitter-link]:              https://gitter.im/https://github.com/CoffeaTeam/fsspec-xrootd/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge
[pypi-link]:                https://pypi.org/project/fsspec-xrootd/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/fsspec-xrootd
[pypi-version]:             https://badge.fury.io/py/fsspec-xrootd.svg
[rtd-badge]:                https://readthedocs.org/projects/fsspec-xrootd/badge/?version=latest
[rtd-link]:                 https://fsspec-xrootd.readthedocs.io/en/latest/?badge=latest
[sk-badge]:                 https://scikit-hep.org/assets/images/Scikit--HEP-Project-blue.svg
<!-- prettier-ignore-end -->

==> fsspec_xrootd-0.2.1.tar.gz: fsspec_xrootd-0.2.1/README.md <==
# fsspec-xrootd

An XRootD implementation for fsspec.

## Install

```bash
pip install fsspec-xrootd
```

## Purpose

To allow fsspec to use XRootD accessible storage systems. Install fsspec-xrootd
alongside fsspec and have easy access to files stored on XRootD serevrs. Once
installed, fsspec will be able to work with urls with the 'root' protocol. Only
tested with Linux at this time.

## Documentation

Please refer to [RTD](https://coffeateam.github.io/fsspec-xrootd/)

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]
[![Code style: black][black-badge]][black-link]

[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

[![GitHub Discussion][github-discussions-badge]][github-discussions-link]
[![Gitter][gitter-badge]][gitter-link]

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/CoffeaTeam/fsspec-xrootd/workflows/CI/badge.svg
[actions-link]:             https://github.com/CoffeaTeam/fsspec-xrootd/actions
[black-badge]:              https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]:               https://github.com/psf/black
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/fsspec-xrootd
[conda-link]:               https://github.com/conda-forge/fsspec-xrootd-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/CoffeaTeam/fsspec-xrootd/discussions
[gitter-badge]:             https://badges.gitter.im/https://github.com/CoffeaTeam/fsspec-xrootd/community.svg
[gitter-link]:              https://gitter.im/https://github.com/CoffeaTeam/fsspec-xrootd/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge
[pypi-link]:                https://pypi.org/project/fsspec-xrootd/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/fsspec-xrootd
[pypi-version]:             https://badge.fury.io/py/fsspec-xrootd.svg
[rtd-badge]:                https://readthedocs.org/projects/fsspec-xrootd/badge/?version=latest
[rtd-link]:                 https://coffeateam.github.io/fsspec-xrootd/
[sk-badge]:                 https://scikit-hep.org/assets/images/Scikit--HEP-Project-blue.svg
<!-- prettier-ignore-end -->
